STARTURL = 'https://www.geocaching.com/account/login?returnUrl='
LOGS_URL = 'https%3A%2F%2Fwww.geocaching.com%2Fmy%2Flogs.aspx%3Fs%3D1'
SOUVENIR_URL = 'https%3A%2F%2Fwww.geocaching.com%2Fmy%2Fsouvenirs.aspx'
